@@ -70,10 +70,10 @@ WEBKIT_DEPRECATED void
 webkit_settings_set_load_icons_ignoring_image_load_setting     (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
-WEBKIT_API gboolean
+WEBKIT_DEPRECATED gboolean
 webkit_settings_get_enable_offline_web_application_cache       (WebKitSettings *settings);
 
-WEBKIT_API void
+WEBKIT_DEPRECATED void
 webkit_settings_set_enable_offline_web_application_cache       (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
@@ -320,6 +320,13 @@ webkit_settings_set_enable_smooth_scrolling                    (WebKitSettings *
                                                                 gboolean        enabled);
 
 
+WEBKIT_API gboolean
+webkit_settings_get_enable_2d_canvas_acceleration              (WebKitSettings *settings);
+
+WEBKIT_API void
+webkit_settings_set_enable_2d_canvas_acceleration              (WebKitSettings *settings,
+                                                                gboolean        enabled);
+
 WEBKIT_API gboolean
 webkit_settings_get_enable_write_console_messages_to_stdout    (WebKitSettings *settings);
 
@@ -447,6 +454,12 @@ webkit_settings_get_experimental_features                      (void);
 WEBKIT_API WebKitFeatureList *
 webkit_settings_get_development_features                       (void);
 
+WEBKIT_API gboolean
+webkit_settings_apply_from_key_file                            (WebKitSettings  *settings,
+                                                                GKeyFile        *key_file,
+                                                                const gchar     *group_name,
+                                                                GError         **error);
+
 G_END_DECLS
 
 #endif /* WebKitSettings_h */
